==> mieru_2.4.2.tar.gz: mieru-2.4.2/mieru/opt/mieru/gui/qml/i18n/qml_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>BitcoinButton</name>
    <message>
        <location filename="../BitcoinButton.qml" line="34"/>
        <source>Bitcoin address</source>
        <translation>Bitcoin adresa</translation>
    </message>
    <message>
        <location filename="../BitcoinButton.qml" line="111"/>
        <source>Copy address</source>
        <translation>Kopírovat adresu</translation>
    </message>
    <message>
        <location filename="../BitcoinButton.qml" line="116"/>
        <source>Bitcoin address copied to clipboard</source>
        <translation>Bitcoin adresa byla skopírována do schránky</translation>
    </message>
</context>
<context>
    <name>FileSelector</name>
    <message>
        <location filename="../FileSelector.qml" line="14"/>
        <source>File Selector</source>
        <translation>Otevřít soubor</translation>
    </message>
</context>
<context>
    <name>FlattrButton</name>
    <message>
        <location filename="../FlattrButton.qml" line="25"/>
        <source>Opening &lt;b&gt;Flattr&lt;/b&gt; donation page, &lt;b&gt;thanks&lt;/b&gt;!</source>
        <translation>Otevírá se stránka pro &lt;b&gt;Flattr&lt;/b&gt; dotace, &lt;b&gt;díky&lt;/b&gt;!</translation>
    </message>
</context>
<context>
    <name>HistoryPage</name>
    <message>
        <location filename="../HistoryPage.qml" line="20"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="31"/>
        <location filename="../HistoryPage.qml" line="118"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="54"/>
        <source>Do not delete items</source>
        <translation>Nic nemazat</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="54"/>
        <source>Delete items</source>
        <translation>Smazat položky</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="57"/>
        <source>Select items to delete</source>
        <translation>Vyberte položky ke smazání</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="61"/>
        <location filename="../HistoryPage.qml" line="115"/>
        <source>Erase history</source>
        <translation>Smazat historii</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="74"/>
        <source>no entries</source>
        <translation>Žádné položky</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="116"/>
        <source>Do you want to erase the history of all mangas and comic books opened by Mieru?</source>
        <translation>Chcete opravdu smazat historii všech mang a komiksů otevřených v Mieru ?</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="117"/>
        <source>Erase</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>InfoPage</name>
    <message>
        <location filename="../InfoPage.qml" line="14"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="18"/>
        <source>Stats</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="22"/>
        <source>About</source>
        <translation>O Mieru</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="77"/>
        <source>Properties</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="80"/>
        <source>Pages</source>
        <translation>Stránek</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="83"/>
        <source>Path</source>
        <translation>Cesta</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="91"/>
        <source>Online search</source>
        <translation>Online hledání</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="97"/>
        <source>Opening &lt;b&gt;Google&lt;/b&gt; search</source>
        <translation>Otevírá se vyhledávání v &lt;b&gt;Googlu&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="106"/>
        <source>Opening &lt;b&gt;Wikipedia&lt;/b&gt; search</source>
        <translation>Otevírá se hledání ve &lt;b&gt;Wikipedii&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="115"/>
        <source>Opening &lt;b&gt;Manga updates&lt;/b&gt; search</source>
        <translation>Otevírá se vyhledávání na &lt;b&gt;Manga updates&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="132"/>
        <source>Usage Statistics</source>
        <translation>Statistika použití</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="162"/>
        <location filename="../InfoPage.qml" line="268"/>
        <source>Reset</source>
        <translation>Vynulovat</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="207"/>
        <source>Mieru is a flexible Manga and comic book reader.</source>
        <translation>Mieru je flexibilní čtečka mangy a komiksu.</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="243"/>
        <source>main developer</source>
        <translation>hlavní vývojář</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="246"/>
        <source>email</source>
        <translation>email</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="250"/>
        <source>www</source>
        <translation>www</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="255"/>
        <source>discussion</source>
        <translation>diskuzní vlákno</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation type="obsolete">Poslat dotaci</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="266"/>
        <source>Reset all usage statistics</source>
        <translation>Vynulovat statistiku použití Mieru</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="267"/>
        <source>Do you really want to reset all usage statistics?</source>
        <translation>Opravdu chcete vynulovat satistiku použití ?</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="269"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../MainView.qml" line="156"/>
        <source>original</source>
        <translation>1:1</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="158"/>
        <source>width</source>
        <translation>na šířku</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="160"/>
        <source>height</source>
        <translation>na výšku</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="162"/>
        <source>screen</source>
        <translation>na obrazovku</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="164"/>
        <source>orient</source>
        <translation>podle rotace</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="171"/>
        <source>most</source>
        <translation>co nejvíce</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="179"/>
        <source>custom</source>
        <translation>vlastní</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="238"/>
        <source>Open file</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="245"/>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="249"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="253"/>
        <source>Options</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="260"/>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="459"/>
        <source>Rotation</source>
        <translation>Uzamčení rotace</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="479"/>
        <source>No pages loaded</source>
        <translation>Žádné stránky nejsou načteny</translation>
    </message>
</context>
<context>
    <name>OptionsPage</name>
    <message>
        <location filename="../OptionsPage.qml" line="25"/>
        <source>Page view</source>
        <translation>Zobrazení stránky</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="28"/>
        <source>Rotation</source>
        <translation>Rotace</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="43"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="51"/>
        <source>portrait</source>
        <translation>na výšku</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="59"/>
        <source>landscape</source>
        <translation>na šířku</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="67"/>
        <source>Show status bar</source>
        <translation>Zobrazit stavovou lištu</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="75"/>
        <source>Remember toolbar state</source>
        <translation>Pamatovat stav nástrojové lišty</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="82"/>
        <source>Fullscreen button opacity</source>
        <translation>Průhlednost tlačítka celé obrazovky</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="108"/>
        <source>Paging options</source>
        <translation>Možnosti listování</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="111"/>
        <source>Paging mode</source>
        <translation>Režim listování</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="126"/>
        <source>Whole screen</source>
        <translation>celá obrazovka</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="134"/>
        <source>On edges</source>
        <translation>pouze kraje</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="142"/>
        <source>Show paging feedback</source>
        <translation>Zpětná vazba</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="152"/>
        <source>Page scaling</source>
        <translation>Škálování stránky</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="155"/>
        <source>Page fit mode</source>
        <translation>Zarovnání stránky</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="164"/>
        <source>Miscellaneous</source>
        <translation>Ostatní</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="167"/>
        <source>Manga reading mode</source>
        <translation>Manga režim</translation>
    </message>
</context>
<context>
    <name>PageFitSelector</name>
    <message>
        <location filename="../PageFitSelector.qml" line="10"/>
        <source>Page fit mode</source>
        <translation>Zarovnání stránky</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="18"/>
        <source>&lt;b&gt;1:1&lt;/b&gt; - original size</source>
        <translation>&lt;b&gt;1:1&lt;/b&gt; - původní velikost</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="19"/>
        <source>&lt;b&gt;fit to width&lt;/b&gt;</source>
        <translation>&lt;b&gt;na šířku&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="20"/>
        <source>&lt;b&gt;fit to height&lt;/b&gt;</source>
        <translation>&lt;b&gt;na výšku&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="21"/>
        <source>&lt;b&gt;fit to screen&lt;/b&gt;</source>
        <translation>&lt;b&gt;na obrazovku&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="22"/>
        <source>&lt;b&gt;custom&lt;/b&gt; - remember scale</source>
        <translation>&lt;b&gt;vlastní&lt;/b&gt; - zpamatovat přiblížení</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="23"/>
        <source>&lt;b&gt;orientation&lt;/b&gt; specific</source>
        <translation>podle &lt;b&gt;rotace přístroje&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="24"/>
        <source>&lt;b&gt;show the most&lt;/b&gt;</source>
        <translation>&lt;b&gt;zobrazit co nejvíce&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>PayPalButton</name>
    <message>
        <location filename="../PayPalButton.qml" line="24"/>
        <source>Opening &lt;b&gt;PayPal&lt;/b&gt; donation page, &lt;b&gt;thanks&lt;/b&gt;!</source>
        <translation>Otevírá se stránka pro &lt;b&gt;PayPal&lt;/b&gt; dotace, &lt;b&gt;díky&lt;/b&gt;!</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="83"/>
        <source>How to turn pages</source>
        <translation>Jak v Mieru funguje listování</translation>
    </message>
    <message>
        <location filename="../main.qml" line="84"/>
        <source>Tap the &lt;b&gt;right half&lt;/b&gt; of the screen to go to the &lt;b&gt;next page&lt;/b&gt;.</source>
        <translation>Dotkněte se &lt;b&gt;levé poloviny obrazovky&lt;/b&gt; pro přechod na &lt;b&gt;další stránku&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../main.qml" line="85"/>
        <source>Tap the &lt;b&gt;left half&lt;/b&gt; to go to the &lt;b&gt;previous page&lt;/b&gt;.</source>
        <translation>Dotkněte se &lt;b&gt;levé poloviny&lt;/b&gt; pro přechod na &lt;b&gt;předchozí stránku&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../main.qml" line="86"/>
        <source>Don&apos;t show again</source>
        <translation>Příště neukazovat</translation>
    </message>
    <message>
        <location filename="../main.qml" line="87"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>

==> mieru_2.4.5.tar.gz: mieru-2.4.5/mieru/opt/mieru/gui/qml/i18n/qml_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>BitcoinButton</name>
    <message>
        <location filename="../BitcoinButton.qml" line="34"/>
        <source>Bitcoin address</source>
        <translation>Bitcoin adresa</translation>
    </message>
    <message>
        <location filename="../BitcoinButton.qml" line="111"/>
        <source>Copy address</source>
        <translation>Kopírovat adresu</translation>
    </message>
    <message>
        <location filename="../BitcoinButton.qml" line="116"/>
        <source>Bitcoin address copied to clipboard</source>
        <translation>Bitcoin adresa byla skopírována do schránky</translation>
    </message>
</context>
<context>
    <name>FileSelector</name>
    <message>
        <location filename="../FileSelector.qml" line="14"/>
        <source>File Selector</source>
        <translation>Otevřít soubor</translation>
    </message>
</context>
<context>
    <name>FlattrButton</name>
    <message>
        <location filename="../FlattrButton.qml" line="25"/>
        <source>Opening &lt;b&gt;Flattr&lt;/b&gt; donation page, &lt;b&gt;thanks&lt;/b&gt;!</source>
        <translation>Otevírá se stránka pro &lt;b&gt;Flattr&lt;/b&gt; dotace, &lt;b&gt;díky&lt;/b&gt;!</translation>
    </message>
</context>
<context>
    <name>HistoryPage</name>
    <message>
        <location filename="../HistoryPage.qml" line="20"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="31"/>
        <location filename="../HistoryPage.qml" line="118"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="54"/>
        <source>Do not delete items</source>
        <translation>Nic nemazat</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="54"/>
        <source>Delete items</source>
        <translation>Smazat položky</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="57"/>
        <source>Select items to delete</source>
        <translation>Vyberte položky ke smazání</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="61"/>
        <location filename="../HistoryPage.qml" line="115"/>
        <source>Erase history</source>
        <translation>Smazat historii</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="74"/>
        <source>no entries</source>
        <translation>Žádné položky</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="116"/>
        <source>Do you want to erase the history of all mangas and comic books opened by Mieru?</source>
        <translation>Chcete opravdu smazat historii všech mang a komiksů otevřených v Mieru ?</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="117"/>
        <source>Erase</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>InfoPage</name>
    <message>
        <location filename="../InfoPage.qml" line="14"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="18"/>
        <source>Stats</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="22"/>
        <source>About</source>
        <translation>O Mieru</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="77"/>
        <source>Properties</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="80"/>
        <source>Pages</source>
        <translation>Stránek</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="83"/>
        <source>Path</source>
        <translation>Cesta</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="91"/>
        <source>Online search</source>
        <translation>Online hledání</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="97"/>
        <source>Opening &lt;b&gt;Google&lt;/b&gt; search</source>
        <translation>Otevírá se vyhledávání v &lt;b&gt;Googlu&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="106"/>
        <source>Opening &lt;b&gt;Wikipedia&lt;/b&gt; search</source>
        <translation>Otevírá se hledání ve &lt;b&gt;Wikipedii&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="115"/>
        <source>Opening &lt;b&gt;Manga updates&lt;/b&gt; search</source>
        <translation>Otevírá se vyhledávání na &lt;b&gt;Manga updates&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="132"/>
        <source>Usage Statistics</source>
        <translation>Statistika použití</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="162"/>
        <location filename="../InfoPage.qml" line="271"/>
        <source>Reset</source>
        <translation>Vynulovat</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="207"/>
        <source>Mieru is a flexible Manga and comic book reader.</source>
        <translation>Mieru je flexibilní čtečka mangy a komiksu.</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="243"/>
        <source>main developer</source>
        <translation>hlavní vývojář</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="246"/>
        <source>email</source>
        <translation>email</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="250"/>
        <source>www</source>
        <translation>www</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="255"/>
        <source>discussion</source>
        <translation>diskuzní vlákno</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation type="obsolete">Poslat dotaci</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="269"/>
        <source>Reset all usage statistics</source>
        <translation>Vynulovat statistiku použití Mieru</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="270"/>
        <source>Do you really want to reset all usage statistics?</source>
        <translation>Opravdu chcete vynulovat satistiku použití ?</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="272"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../MainView.qml" line="156"/>
        <source>original</source>
        <translation>1:1</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="158"/>
        <source>width</source>
        <translation>na šířku</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="160"/>
        <source>height</source>
        <translation>na výšku</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="162"/>
        <source>screen</source>
        <translation>na obrazovku</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="164"/>
        <source>orient</source>
        <translation>podle rotace</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="171"/>
        <source>most</source>
        <translation>co nejvíce</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="179"/>
        <source>custom</source>
        <translation>vlastní</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="238"/>
        <source>Open file</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="245"/>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="249"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="253"/>
        <source>Options</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="260"/>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="459"/>
        <source>Rotation</source>
        <translation>Uzamčení rotace</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="479"/>
        <source>No pages loaded</source>
        <translation>Žádné stránky nejsou načteny</translation>
    </message>
</context>
<context>
    <name>OptionsPage</name>
    <message>
        <location filename="../OptionsPage.qml" line="27"/>
        <source>Page view</source>
        <translation>Zobrazení stránky</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="30"/>
        <source>Rotation</source>
        <translation>Rotace</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="45"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="53"/>
        <source>portrait</source>
        <translation>na výšku</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="61"/>
        <source>landscape</source>
        <translation>na šířku</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="69"/>
        <source>Show status bar</source>
        <translation>Zobrazit stavovou lištu</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="77"/>
        <source>Remember toolbar state</source>
        <translation>Pamatovat stav nástrojové lišty</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="84"/>
        <source>Fullscreen button opacity</source>
        <translation>Průhlednost tlačítka celé obrazovky</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="110"/>
        <source>Paging options</source>
        <translation>Možnosti listování</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="113"/>
        <source>Paging mode</source>
        <translation>Režim listování</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="128"/>
        <source>Whole screen</source>
        <translation>celá obrazovka</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="136"/>
        <source>On edges</source>
        <translation>pouze kraje</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="144"/>
        <source>Show paging feedback</source>
        <translation>Zpětná vazba</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="154"/>
        <source>Page scaling</source>
        <translation>Škálování stránky</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="157"/>
        <source>Page fit mode</source>
        <translation>Zarovnání stránky</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="166"/>
        <source>Miscellaneous</source>
        <translation>Ostatní</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="169"/>
        <source>Manga reading mode</source>
        <translation>Manga režim</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="177"/>
        <source>Show release notes</source>
        <translation>Poznámky k vydání</translation>
    </message>
</context>
<context>
    <name>PageFitSelector</name>
    <message>
        <location filename="../PageFitSelector.qml" line="10"/>
        <source>Page fit mode</source>
        <translation>Zarovnání stránky</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="18"/>
        <source>&lt;b&gt;1:1&lt;/b&gt; - original size</source>
        <translation>&lt;b&gt;1:1&lt;/b&gt; - původní velikost</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="19"/>
        <source>&lt;b&gt;fit to width&lt;/b&gt;</source>
        <translation>&lt;b&gt;na šířku&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="20"/>
        <source>&lt;b&gt;fit to height&lt;/b&gt;</source>
        <translation>&lt;b&gt;na výšku&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="21"/>
        <source>&lt;b&gt;fit to screen&lt;/b&gt;</source>
        <translation>&lt;b&gt;na obrazovku&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="22"/>
        <source>&lt;b&gt;custom&lt;/b&gt; - remember scale</source>
        <translation>&lt;b&gt;vlastní&lt;/b&gt; - zpamatovat přiblížení</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="23"/>
        <source>&lt;b&gt;orientation&lt;/b&gt; specific</source>
        <translation>podle &lt;b&gt;rotace přístroje&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="24"/>
        <source>&lt;b&gt;show the most&lt;/b&gt;</source>
        <translation>&lt;b&gt;zobrazit co nejvíce&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>PayPalButton</name>
    <message>
        <location filename="../PayPalButton.qml" line="24"/>
        <source>Opening &lt;b&gt;PayPal&lt;/b&gt; donation page, &lt;b&gt;thanks&lt;/b&gt;!</source>
        <translation>Otevírá se stránka pro &lt;b&gt;PayPal&lt;/b&gt; dotace, &lt;b&gt;díky&lt;/b&gt;!</translation>
    </message>
</context>
<context>
    <name>WhatsNewDialog</name>
    <message>
        <location filename="../WhatsNewDialog.qml" line="35"/>
        <source>Opening link</source>
        <translation>Otevírám odkaz</translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="48"/>
        <source>&lt;b&gt;Do you like Mieru ? Donate !&lt;/b&gt;</source>
        <translation type="unfinished">&lt;b&gt;Líbí se Vám Mieru ? Příspějte!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="56"/>
        <source>How to donate ?</source>
        <translation>Jak přizpět ?</translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="67"/>
        <source>Don&apos;t show again</source>
        <translation>Příště neukazovat</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="85"/>
        <source>How to turn pages</source>
        <translation>Jak v Mieru funguje listování</translation>
    </message>
    <message>
        <location filename="../main.qml" line="86"/>
        <source>Tap the &lt;b&gt;right half&lt;/b&gt; of the screen to go to the &lt;b&gt;next page&lt;/b&gt;.</source>
        <translation>Dotkněte se &lt;b&gt;levé poloviny obrazovky&lt;/b&gt; pro přechod na &lt;b&gt;další stránku&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../main.qml" line="87"/>
        <source>Tap the &lt;b&gt;left half&lt;/b&gt; to go to the &lt;b&gt;previous page&lt;/b&gt;.</source>
        <translation>Dotkněte se &lt;b&gt;levé poloviny&lt;/b&gt; pro přechod na &lt;b&gt;předchozí stránku&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../main.qml" line="88"/>
        <source>Don&apos;t show again</source>
        <translation>Příště neukazovat</translation>
    </message>
    <message>
        <location filename="../main.qml" line="89"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>
